
import React from "react";
import { errorReporter } from "@/utils/errorReporting";
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { AuthProvider } from "@/hooks/useAuth";
import { ProtectedRoute } from "@/components/ProtectedRoute";
import { AdminGuard } from "@/components/AdminGuard";
import { ThemeProvider } from "@/components/ThemeProvider";
import ErrorBoundary from "@/components/ErrorBoundary";
import { CookieProvider } from "@/components/cookies/CookieProvider";
import { CookieConsent } from "@/components/cookies/CookieConsent";
import { CookieSettings } from "@/components/cookies/CookieSettings";

import Landing from "./pages/Landing";
import Index from "./pages/Index";
import Auth from "./pages/Auth";
import Practice from "./pages/Practice";
import Review from "./pages/Review";
import Resources from "./pages/Resources";
import Settings from "./pages/Settings";
import StudySchedule from "./pages/StudySchedule";
import Learning from "./pages/Learning";
import Blog from "./pages/Blog";
import BlogPost from "./pages/BlogPost";
import EmailCenter from "./pages/EmailCenter";

import Waitlist from "./pages/Waitlist";
import Privacy from "./pages/Privacy";
import Terms from "./pages/Terms";
import Support from "./pages/Support";
import { Staff } from "./pages/Staff";
import NotFound from "./pages/NotFound";

// Optimized React Query client with better defaults
const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      staleTime: 5 * 60 * 1000, // 5 minutes
      gcTime: 10 * 60 * 1000, // 10 minutes (formerly cacheTime)
      retry: (failureCount, error: any) => {
        // Don't retry on 4xx errors
        if (error?.status >= 400 && error?.status < 500) return false;
        return failureCount < 2;
      },
      refetchOnWindowFocus: false,
    },
    mutations: {
      retry: 1,
    },
  },
});

const App = () => {
  React.useEffect(() => {
    // Initialize error reporting
    errorReporter;
    
    // Prevent GA script conflicts with React
    const preventGAErrors = () => {
      if (typeof window !== 'undefined' && (window as any).gtag) {
        const originalGtag = (window as any).gtag;
        (window as any).gtag = (...args: any[]) => {
          try {
            return originalGtag(...args);
          } catch (error) {
            console.warn('GA tracking error prevented:', error);
            errorReporter.reportError(error as Error, { component: 'GoogleAnalytics' });
          }
        };
      }
    };
    preventGAErrors();
  }, []);

  return (
    <ErrorBoundary>
      <QueryClientProvider client={queryClient}>
        <ThemeProvider defaultTheme="light" storageKey="study-app-theme">
          <TooltipProvider>
            <CookieProvider>
              <Toaster />
              <Sonner />
            <BrowserRouter>
              <AuthProvider>
                <AdminGuard>
                  <Routes>
                    {/* Public routes */}
                    <Route path="/privacy" element={<Privacy />} />
                    <Route path="/terms" element={<Terms />} />
                    <Route path="/waitlist" element={<Waitlist />} />
                    <Route path="/" element={<Landing />} />
                    <Route path="/blog" element={<Blog />} />
                    <Route path="/blog/:slug" element={<BlogPost />} />
                    <Route path="/auth" element={<Auth />} />
                    <Route path="/support" element={<Support />} />
                    <Route path="/staff" element={<Staff />} />
                    
                    {/* Protected routes that require authentication */}
                    <Route path="/dashboard" element={
                      <ProtectedRoute>
                        <Index />
                      </ProtectedRoute>
                    } />
                    <Route path="/practice" element={
                      <ProtectedRoute>
                        <Practice />
                      </ProtectedRoute>
                    } />
                    <Route path="/review" element={
                      <ProtectedRoute>
                        <Review />
                      </ProtectedRoute>
                    } />
                    <Route path="/resources" element={
                      <ProtectedRoute>
                        <Resources />
                      </ProtectedRoute>
                    } />
                    <Route path="/settings" element={
                      <ProtectedRoute>
                        <Settings />
                      </ProtectedRoute>
                    } />
                    <Route path="/schedule" element={
                      <ProtectedRoute>
                        <StudySchedule />
                      </ProtectedRoute>
                    } />
                    <Route path="/learning" element={
                      <ProtectedRoute>
                        <Learning />
                      </ProtectedRoute>
                    } />
                    <Route path="/email" element={
                      <ProtectedRoute>
                        <EmailCenter />
                      </ProtectedRoute>
                    } />
                    <Route path="*" element={<NotFound />} />
                  </Routes>
                </AdminGuard>
                <CookieConsent />
                <CookieSettings />
              </AuthProvider>
            </BrowserRouter>
          </CookieProvider>
        </TooltipProvider>
      </ThemeProvider>
    </QueryClientProvider>
  </ErrorBoundary>
  );
};

export default App;
